==> fivem-docker-cli-0.0.433.tgz: package/README.md <==
fivem-docker-cli ****Under Development**
================

Command-line tool to create and administer FiveM Servers running in Docker.

[![oclif](https://img.shields.io/badge/cli-oclif-brightgreen.svg)](https://oclif.io)
[![Version](https://img.shields.io/npm/v/fivem-docker-cli.svg)](https://npmjs.org/package/fivem-docker-cli)
[![Downloads/week](https://img.shields.io/npm/dw/fivem-docker-cli.svg)](https://npmjs.org/package/fivem-docker-cli)
[![License](https://img.shields.io/npm/l/fivem-docker-cli.svg)](https://github.com/justweb1/fivem-docker-cli/blob/master/package.json)

<!-- toc -->
* [Usage](#usage)
* [Commands](#commands)
<!-- tocstop -->
# Usage
<!-- usage -->
```sh-session
$ npm install -g fivem-docker-cli
$ fivem COMMAND
running command...
$ fivem (-v|--version|version)
fivem-docker-cli/0.0.433 win32-x64 node-v8.11.3
$ fivem --help [COMMAND]
USAGE
  $ fivem COMMAND
...
```
<!-- usagestop -->
# Commands
<!-- commands -->
* [`fivem autocomplete [SHELL]`](#fivem-autocomplete-shell)
* [`fivem help [COMMAND]`](#fivem-help-command)
* [`fivem init`](#fivem-init)
* [`fivem restart`](#fivem-restart)
* [`fivem start`](#fivem-start)
* [`fivem status`](#fivem-status)
* [`fivem stop`](#fivem-stop)
* [`fivem update [CHANNEL]`](#fivem-update-channel)

## `fivem autocomplete [SHELL]`

display autocomplete installation instructions

```
USAGE
  $ fivem autocomplete [SHELL]

ARGUMENTS
  SHELL  shell type

OPTIONS
  -r, --refresh-cache  Refresh cache (ignores displaying instructions)

EXAMPLES
  $ fivem autocomplete
  $ fivem autocomplete bash
  $ fivem autocomplete zsh
  $ fivem autocomplete --refresh-cache
```

_See code: [@oclif/plugin-autocomplete](https://github.com/oclif/plugin-autocomplete/blob/v0.1.0/src\commands\autocomplete\index.ts)_

## `fivem help [COMMAND]`

display help for fivem

```
USAGE
  $ fivem help [COMMAND]

ARGUMENTS
  COMMAND  command to show help for

OPTIONS
  --all  see all commands in CLI
```

_See code: [@oclif/plugin-help](https://github.com/oclif/plugin-help/blob/v2.1.4/src\commands\help.ts)_

## `fivem init`

Creates a new FiveM server running in Docker

```
USAGE
  $ fivem init

OPTIONS
  -k, --licensekey=licensekey  Server license key - This can be obtained from https://keymaster.fivem.net.
  -p, --rconpass=rconpass      Password for RCON access.
  -s, --servername=servername  Name of the FiveM Docker container.
```

_See code: [src\commands\init.js](https://github.com/justweb1/fivem-docker-cli/blob/v0.0.433/src\commands\init.js)_

## `fivem restart`

Describe the command here

```
USAGE
  $ fivem restart

OPTIONS
  -n, --name=name  name to print

DESCRIPTION
  ...
  Extra documentation goes here
```

_See code: [src\commands\restart.js](https://github.com/justweb1/fivem-docker-cli/blob/v0.0.433/src\commands\restart.js)_

## `fivem start`

Starts a FiveM server Docker container.

```
USAGE
  $ fivem start

OPTIONS
  -i, --serverid=serverid      ID of the FiveM Docker container.
  -s, --servername=servername  Name of the FiveM Docker container.
```

_See code: [src\commands\start.js](https://github.com/justweb1/fivem-docker-cli/blob/v0.0.433/src\commands\start.js)_

## `fivem status`

Display status of all FiveM server Docker containers.

```
USAGE
  $ fivem status
```

_See code: [src\commands\status.js](https://github.com/justweb1/fivem-docker-cli/blob/v0.0.433/src\commands\status.js)_

## `fivem stop`

Starts a FiveM server Docker container.

```
USAGE
  $ fivem stop

OPTIONS
  -i, --serverid=serverid      ID of the FiveM Docker container.
  -s, --servername=servername  Name of the FiveM Docker container.
```

_See code: [src\commands\stop.js](https://github.com/justweb1/fivem-docker-cli/blob/v0.0.433/src\commands\stop.js)_

## `fivem update [CHANNEL]`

update the fivem CLI

```
USAGE
  $ fivem update [CHANNEL]
```

_See code: [@oclif/plugin-update](https://github.com/oclif/plugin-update/blob/v1.3.7/src\commands\update.ts)_
<!-- commandsstop -->

==> fivem-docker-cli-0.1.4.tgz: package/README.md <==
fivem-docker-cli
================
[![oclif](https://img.shields.io/badge/cli-oclif-brightgreen.svg)](https://oclif.io)
[![Version](https://img.shields.io/npm/v/fivem-docker-cli.svg)](https://npmjs.org/package/fivem-docker-cli)
[![Downloads/week](https://img.shields.io/npm/dw/fivem-docker-cli.svg)](https://npmjs.org/package/fivem-docker-cli)
[![License](https://img.shields.io/npm/l/fivem-docker-cli.svg)](https://github.com/justweb1/fivem-docker-cli/blob/master/package.json)

## ** Under Development - Use at your own risk. **
Command-line tool to create and administer FiveM Servers running in Docker.

* [Prerequisites](#prerequisites)
<!-- toc -->
* [Prerequisites](#prerequisites)
* [Usage](#usage)
* [Commands](#commands)
<!-- tocstop -->

# Prerequisites
<!-- prerequisites -->
* Linux-based OS (preferably CentOS)
* Docker (tested on v0.1.13)
* Node/NPM
<!-- prerequisitesstop -->

# Usage
<!-- usage -->
```sh-session
$ npm install -g fivem-docker-cli
$ fivem COMMAND
running command...
$ fivem (-v|--version|version)
fivem-docker-cli/0.1.4 win32-x64 node-v8.11.3
$ fivem --help [COMMAND]
USAGE
  $ fivem COMMAND
...
```
<!-- usagestop -->

# Commands
<!-- commands -->
* [`fivem delete`](#fivem-delete)
* [`fivem help [COMMAND]`](#fivem-help-command)
* [`fivem init`](#fivem-init)
* [`fivem restart`](#fivem-restart)
* [`fivem start`](#fivem-start)
* [`fivem status`](#fivem-status)
* [`fivem stop`](#fivem-stop)

## `fivem delete`

Deletes a FiveM server Docker container.

```
USAGE
  $ fivem delete

OPTIONS
  -i, --serverid=serverid      ID of the FiveM Docker container.
  -s, --servername=servername  Name of the FiveM Docker container.
```

_See code: [src\commands\delete.js](https://github.com/justweb1/fivem-docker-cli/blob/v0.1.4/src\commands\delete.js)_

## `fivem help [COMMAND]`

display help for fivem

```
USAGE
  $ fivem help [COMMAND]

ARGUMENTS
  COMMAND  command to show help for

OPTIONS
  --all  see all commands in CLI
```

_See code: [@oclif/plugin-help](https://github.com/oclif/plugin-help/blob/v2.1.4/src\commands\help.ts)_

## `fivem init`

Creates a new FiveM server running in Docker.

```
USAGE
  $ fivem init

OPTIONS
  -k, --licensekey=licensekey  Server license key - This can be obtained from https://keymaster.fivem.net.
  -p, --rconpass=rconpass      Password for RCON access.
  -s, --servername=servername  Name of the FiveM Docker container.
```

_See code: [src\commands\init.js](https://github.com/justweb1/fivem-docker-cli/blob/v0.1.4/src\commands\init.js)_

## `fivem restart`

Restarts a FiveM server Docker container.

```
USAGE
  $ fivem restart

OPTIONS
  -i, --serverid=serverid      ID of the FiveM Docker container.
  -s, --servername=servername  Name of the FiveM Docker container.
```

_See code: [src\commands\restart.js](https://github.com/justweb1/fivem-docker-cli/blob/v0.1.4/src\commands\restart.js)_

## `fivem start`

Starts a FiveM server Docker container.

```
USAGE
  $ fivem start

OPTIONS
  -i, --serverid=serverid      ID of the FiveM Docker container.
  -s, --servername=servername  Name of the FiveM Docker container.
```

_See code: [src\commands\start.js](https://github.com/justweb1/fivem-docker-cli/blob/v0.1.4/src\commands\start.js)_

## `fivem status`

Display status of all FiveM server Docker containers.

```
USAGE
  $ fivem status
```

_See code: [src\commands\status.js](https://github.com/justweb1/fivem-docker-cli/blob/v0.1.4/src\commands\status.js)_

## `fivem stop`

Stops a FiveM server Docker container.

```
USAGE
  $ fivem stop

OPTIONS
  -i, --serverid=serverid      ID of the FiveM Docker container.
  -s, --servername=servername  Name of the FiveM Docker container.
```

_See code: [src\commands\stop.js](https://github.com/justweb1/fivem-docker-cli/blob/v0.1.4/src\commands\stop.js)_
<!-- commandsstop -->
